pub enum Permit2Errors {
AllowanceExpired(AllowanceExpired),
ExcessiveInvalidation(ExcessiveInvalidation),
InsufficientAllowance(InsufficientAllowance),
InvalidAmount(InvalidAmount),
InvalidContractSignature(InvalidContractSignature),
InvalidNonce(InvalidNonce),
InvalidSignature(InvalidSignature),
InvalidSignatureLength(InvalidSignatureLength),
InvalidSigner(InvalidSigner),
LengthMismatch(LengthMismatch),
SignatureExpired(SignatureExpired),
}Expand description
Container for all the Permit2 custom errors.
Variants
AllowanceExpired(AllowanceExpired)
ExcessiveInvalidation(ExcessiveInvalidation)
InsufficientAllowance(InsufficientAllowance)
InvalidAmount(InvalidAmount)
InvalidContractSignature(InvalidContractSignature)
InvalidNonce(InvalidNonce)
InvalidSignature(InvalidSignature)
InvalidSignatureLength(InvalidSignatureLength)
InvalidSigner(InvalidSigner)
LengthMismatch(LengthMismatch)
SignatureExpired(SignatureExpired)
Implementations
Sourceimpl Permit2Errors
impl Permit2Errors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl Permit2Errors
impl Permit2Errors
Sourcepub fn allowance_expired(deadline: U256) -> Self
pub fn allowance_expired(deadline: U256) -> Self
Creates a AllowanceExpired error.
error AllowanceExpired(uint256)Sourcepub fn excessive_invalidation() -> Self
pub fn excessive_invalidation() -> Self
Creates a ExcessiveInvalidation error.
error ExcessiveInvalidation()Sourcepub fn insufficient_allowance(amount: U256) -> Self
pub fn insufficient_allowance(amount: U256) -> Self
Creates a InsufficientAllowance error.
error InsufficientAllowance(uint256)Sourcepub fn invalid_amount(max_amount: U256) -> Self
pub fn invalid_amount(max_amount: U256) -> Self
Creates a InvalidAmount error.
error InvalidAmount(uint256)Sourcepub fn invalid_contract_signature() -> Self
pub fn invalid_contract_signature() -> Self
Creates a InvalidContractSignature error.
error InvalidContractSignature()Sourcepub fn invalid_nonce() -> Self
pub fn invalid_nonce() -> Self
Creates a InvalidNonce error.
error InvalidNonce()Sourcepub fn invalid_signature() -> Self
pub fn invalid_signature() -> Self
Creates a InvalidSignature error.
error InvalidSignature()Sourcepub fn invalid_signature_length() -> Self
pub fn invalid_signature_length() -> Self
Creates a InvalidSignatureLength error.
error InvalidSignatureLength()Sourcepub fn invalid_signer() -> Self
pub fn invalid_signer() -> Self
Creates a InvalidSigner error.
error InvalidSigner()Sourcepub fn length_mismatch() -> Self
pub fn length_mismatch() -> Self
Creates a LengthMismatch error.
error LengthMismatch()Sourcepub fn signature_expired(signature_deadline: U256) -> Self
pub fn signature_expired(signature_deadline: U256) -> Self
Creates a SignatureExpired error.
error SignatureExpired(uint256)Trait Implementations
Sourceimpl Clone for Permit2Errors
impl Clone for Permit2Errors
Sourcefn clone(&self) -> Permit2Errors
fn clone(&self) -> Permit2Errors
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<'de> Deserialize<'de> for Permit2Errors
impl<'de> Deserialize<'de> for Permit2Errors
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Serialize for Permit2Errors
impl Serialize for Permit2Errors
Sourceimpl SolInterface for Permit2Errors
impl SolInterface for Permit2Errors
Sourceconst MIN_DATA_LENGTH: usize = 0usize
const MIN_DATA_LENGTH: usize = 0usize
Sourcefn valid_selector(selector: [u8; 4]) -> bool
fn valid_selector(selector: [u8; 4]) -> bool
true if the given selector is known to this type.Sourcefn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw(selector: [u8; 4], data: &[u8]) -> Result<Self>
self.Sourcefn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(selector: [u8; 4], data: &[u8]) -> Result<Self>
self, with validation. Read moreSourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
self into the given buffer, without any selectors.fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn type_check(selector: [u8; 4]) -> Result<(), Error>
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
self into the given buffer.fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
self.fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
self, with validation. Read moreAuto Trait Implementations
impl Freeze for Permit2Errors
impl RefUnwindSafe for Permit2Errors
impl Send for Permit2Errors
impl Sync for Permit2Errors
impl Unpin for Permit2Errors
impl UnsafeUnpin for Permit2Errors
impl UnwindSafe for Permit2Errors