pub enum Permit2Events {
Approval(Approval),
Lockdown(Lockdown),
NonceInvalidation(NonceInvalidation),
Permit(Permit),
UnorderedNonceInvalidation(UnorderedNonceInvalidation),
}Expand description
Container for all the Permit2 events.
Variants
Approval(Approval)
Lockdown(Lockdown)
NonceInvalidation(NonceInvalidation)
Permit(Permit)
UnorderedNonceInvalidation(UnorderedNonceInvalidation)
Implementations
Sourceimpl Permit2Events
impl Permit2Events
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl Permit2Events
impl Permit2Events
Sourcepub fn approval(
owner: Address,
token: Address,
spender: Address,
amount: U160,
expiration: U48,
) -> Self
pub fn approval( owner: Address, token: Address, spender: Address, amount: U160, expiration: U48, ) -> Self
Creates a Approval event.
event Approval(address,address,address,uint160,uint48)Sourcepub fn lockdown(owner: Address, token: Address, spender: Address) -> Self
pub fn lockdown(owner: Address, token: Address, spender: Address) -> Self
Creates a Lockdown event.
event Lockdown(address,address,address)Sourcepub fn nonce_invalidation(
owner: Address,
token: Address,
spender: Address,
new_nonce: U48,
old_nonce: U48,
) -> Self
pub fn nonce_invalidation( owner: Address, token: Address, spender: Address, new_nonce: U48, old_nonce: U48, ) -> Self
Creates a NonceInvalidation event.
event NonceInvalidation(address,address,address,uint48,uint48)Sourcepub fn permit(
owner: Address,
token: Address,
spender: Address,
amount: U160,
expiration: U48,
nonce: U48,
) -> Self
pub fn permit( owner: Address, token: Address, spender: Address, amount: U160, expiration: U48, nonce: U48, ) -> Self
Creates a Permit event.
event Permit(address,address,address,uint160,uint48,uint48)Sourcepub fn unordered_nonce_invalidation(
owner: Address,
word: U256,
mask: U256,
) -> Self
pub fn unordered_nonce_invalidation( owner: Address, word: U256, mask: U256, ) -> Self
Creates a UnorderedNonceInvalidation event.
event UnorderedNonceInvalidation(address,uint256,uint256)Trait Implementations
Sourceimpl Clone for Permit2Events
impl Clone for Permit2Events
Sourcefn clone(&self) -> Permit2Events
fn clone(&self) -> Permit2Events
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<'de> Deserialize<'de> for Permit2Events
impl<'de> Deserialize<'de> for Permit2Events
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl IntoLogData for Permit2Events
impl IntoLogData for Permit2Events
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.Sourceimpl Serialize for Permit2Events
impl Serialize for Permit2Events
Sourceimpl SolEventInterface for Permit2Events
impl SolEventInterface for Permit2Events
Sourcefn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>